/**
 * Copyright 2009 Ashley Williams
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package protoj.lang.command;

import joptsimple.OptionSet;
import joptsimple.OptionSpec;
import protoj.lang.Command;
import protoj.lang.CommandStore;
import protoj.lang.CompileFeature;
import protoj.lang.StandardProject;

/**
 * Command handler that delegates to the compile functionality. See
 * {@link CompileFeature}.
 * 
 * @author Ashley Williams
 * 
 */
public final class CompileCommand {
	private final class Body implements Runnable {
		public void run() {
			OptionSet options = delegate.getOptions();

			String includes = options.valueOf(includesOption);
			if (includes == null) {
				includes = "*";
			}
			String excludes = options.valueOf(excludesOption);
			parent.getCompileFeature().compile(includes, excludes);
		}
	}

	/**
	 * Provides the basic command functionality.
	 */
	private Command delegate;

	/**
	 * The parent of this command.
	 */
	private final StandardProject parent;

	private OptionSpec<String> includesOption;

	private OptionSpec<String> excludesOption;

	public CompileCommand(StandardProject parent) {
		this.parent = parent;
		CommandStore store = parent.getCommandStore();
		delegate = store.addCommand("compile", "16m", new Body());
		delegate.initHelpResource("/protoj/language/english/compile.txt");
		delegate.initBootstrapCurrentVm();
		delegate.initAliases("build");
		includesOption = delegate.getParser().accepts(getIncludesOption())
				.withRequiredArg();
		excludesOption = delegate.getParser().accepts(getExcludesOption())
				.withRequiredArg();
	}

	public String getExcludesOption() {
		return "excludes";
	}

	public String getIncludesOption() {
		return "includes";
	}

	public Command getDelegate() {
		return delegate;
	}

}
