/**
 * Copyright 2009 Ashley Williams
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package protoj.lang.command;

import joptsimple.OptionSet;
import joptsimple.OptionSpec;
import protoj.lang.Command;
import protoj.lang.CommandStore;
import protoj.lang.DirconfFeature;
import protoj.lang.ScpconfFeature;
import protoj.lang.StandardProject;

/**
 * Command line access to the {@link ScpconfFeature} pojo. See the dirconf.txt
 * file for help.
 * 
 * @author Ashley Williams
 * 
 */
public final class DirconfCommand {

	public final class Body implements Runnable {
		public void run() {
			OptionSet options = getDelegate().getOptions();
			DirconfFeature feature = project.getDirconfFeature();

			if (!options.has(nameOption)) {
				String hint = "the name option is mandatory";
				delegate.throwBadOptionsException(hint);
			}

			String name = options.valueOf(nameOption);
			boolean interpolate = options.has(interpolateOption);

			if (options.has(cleanOption)) {
				feature.clean(name);
			} else {
				feature.configure(name, interpolate);
			}
		}
	}

	/**
	 * Provides the basic command functionality.
	 */
	private Command delegate;
	private OptionSpec<?> interpolateOption;
	private OptionSpec<?> cleanOption;
	private final StandardProject project;
	private OptionSpec<String> nameOption;

	public DirconfCommand(StandardProject project) {
		this.project = project;
		CommandStore store = project.getCommandStore();
		delegate = store.addCommand("dirconf", "32m", new Body());
		delegate.initHelpResource("/protoj/language/english/dirconf.txt");
		delegate.initBootstrapCurrentVm();
		interpolateOption = delegate.getParser()
				.accepts(getInterpolateOption());
		cleanOption = delegate.getParser().accepts(getCleanOption());
		nameOption = delegate.getParser().accepts(getNameOption())
				.withRequiredArg();
	}

	public String getCleanOption() {
		return "clean";
	}

	public String getNameOption() {
		return "name";
	}

	public String getInterpolateOption() {
		return "interpolate";
	}

	public Command getDelegate() {
		return delegate;
	}
}
