/**
 * Copyright 2009 Ashley Williams
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package protoj.lang.command;

import java.util.List;

import joptsimple.OptionSet;
import protoj.lang.Command;
import protoj.lang.CommandStore;
import protoj.lang.InfoFeature;
import protoj.lang.PropertyInfo;
import protoj.lang.StandardProject;

/**
 * The command responsible for reporting help information to the console. See
 * {@link InfoFeature}.
 * 
 * @author Ashley Williams
 * 
 */
public final class HelpCommand {
	private final class Body implements Runnable {
		public void run() {
			OptionSet options = delegate.getOptions();
			List<String> args = options.nonOptionArguments();
			String name = args.size() > 0 ? args.get(0) : null;

			Command command = project.getCommandStore().getCommand(name);
			PropertyInfo property = project.getPropertyStore().getInfo(name);
			if ((command != null)) {
				project.getInfoFeature().reportCommandHelp(command);
			} else if ((property != null)) {
				project.getInfoFeature().reportPropertyHelp(property);
			} else {
				project.getInfoFeature().reportProjectHelp();
			}

		}
	}

	/**
	 * Provides the basic command functionality.
	 */
	private Command delegate;

	/**
	 * The parent of this command.
	 */
	private final StandardProject project;

	public HelpCommand(StandardProject project) {
		this.project = project;
		CommandStore store = project.getCommandStore();
		delegate = store.addCommand("help", "16m", new Body());
		delegate.initHelpResource("/protoj/language/english/help.txt");
		delegate.initAliases("-help", "--help", "h", "-h", "--h", "?");
	}

	public Command getDelegate() {
		return delegate;
	}

}
