/**
 * Copyright 2009 Ashley Williams
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package protoj.lang.command;

import joptsimple.OptionSet;
import joptsimple.OptionSpec;
import protoj.lang.Command;
import protoj.lang.CommandStore;
import protoj.lang.StandardProject;

/**
 * The command responsible for creating the project tar.
 * 
 * @author Ashley Williams
 * 
 */
public final class TarCommand {

	private final class Body implements Runnable {

		public void run() {
			OptionSet options = getDelegate().getOptions();
			boolean noSrc = options.has(nosrc);
			boolean isRwx = options.has(rwx);
			project.getArchiveFeature().getProjectArchive().createArchive(
					noSrc, true, isRwx);
		}
	}

	/**
	 * Provides the basic command functionality.
	 */
	private Command delegate;
	private OptionSpec<?> nosrc;
	private OptionSpec<?> rwx;
	private final StandardProject project;

	public TarCommand(StandardProject project) {
		this.project = project;
		CommandStore store = project.getCommandStore();
		delegate = store.addCommand("tar", "16m", new Body());
		delegate.initHelpResource("/protoj/language/english/tar.txt");
		delegate.initAliases("gtar", "package");
		nosrc = delegate.getParser().accepts(getNosrcOption());
		rwx = delegate.getParser().accepts(getRwxOption());
	}

	public String getRwxOption() {
		return "rwx";
	}

	public String getNosrcOption() {
		return "nosrc";
	}

	public Command getDelegate() {
		return delegate;
	}
}
